@@ -1,6 +1,6 @@
 package pip;
 
-use 5.005;
+use 5.00503;
 use strict;
 use File::Spec         ();
 use File::Temp         ();
@@ -11,7 +11,7 @@ use Module::Plan::Base ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.13';
+	$VERSION = '1.16';
 }
 
 
@@ -33,7 +33,7 @@ sub main {
 	}
 
 	# If the first argument is a file, install it
-	if ( $ARGV[0] =~ /^http\:\/\// ) {
+	if ( $ARGV[0] =~ /^https?\:\/\// ) {
 		return fetch_any($ARGV[0]);
 	}
 	if ( -f $ARGV[0] ) {
@@ -46,8 +46,9 @@ sub main {
 sub fetch_any {
 	my $uri = $_[0];
 
-	# Handle tarballs via a custom Module::Plan::Lite object
-	if ( $uri =~ /\.tar\.gz/ ) {
+	# Handle tarballs via a custom Module::Plan::Lite object.
+	# Also handle PAR archives
+	if ( $uri =~ /\.(?:par|zip|tar\.gz)$/  ) {
 		require Module::Plan::Lite;
 		my $plan = Module::Plan::Lite->new(
 			p5i   => 'default.p5i',
@@ -88,16 +89,21 @@ sub install_any {
 sub read_any {
 	my $param = $_[0];
 
+	# If the first argument is a tar.gz file, hand off to install
+	if ( $param =~ /\.(?:zip|tar\.gz)$/ ) {
+		return read_archive(@_);
+	}
+
+	# If the first argument is a par file, hand off to install
+	if ( $param =~ /\.par$/ ) {
+		return read_archive(@_);
+	}
+
 	# If the first argument is a p5i file, hand off to read
 	if ( $param =~ /\.p5i$/ ) {
 		return read_p5i(@_);
 	}
 
-	# If the first argument is a tar.gz file, hand off to install
-	if ( $param =~ /\.tar\.gz$/ ) {
-		return read_tarball(@_);
-	}
-
 	# If the first argument is a p5z file, hand off to instal
 	if ( $param =~ /\.p5z$/ ) {
 		return read_p5z(@_);
@@ -145,15 +151,15 @@ sub read_p5i {
 	return $plan;
 }
 
-sub read_tarball {
-	my $targz = File::Spec->rel2abs(shift);
-	unless ( -f $targz ) {
-		error("Filed does no exist: $targz");
+sub read_archive {
+	my $archive = File::Spec->rel2abs(shift);
+	unless ( -f $archive ) {
+		error("Filed does no exist: $archive");
 	}
 	require Module::Plan::Lite;
 	Module::Plan::Lite->new(
 		p5i   => 'default.p5i',
-		lines => [ '', URI::file->new($targz)->as_string ],
+		lines => [ '', URI::file->new($archive)->as_string ],
 		);
 }
 
@@ -358,7 +364,7 @@ L<Module::Plan::Base>, L<Module::Plan::Lite>, L<Module::Plan>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2007 Adam Kennedy.
+Copyright 2006 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
